searchNodes=[{"ref":"BitOps.html","title":"BitOps","type":"module","doc":"BitOps provides bit-level operations on integers. This is a low level utility module to support UintSet. All the functions take an integer as the first argument; most return new integers by flipping bits on the first argument, returning the value of a specific bit, or finding bits set to 1."},{"ref":"BitOps.html#count_ones/1","title":"BitOps.count_ones/1","type":"function","doc":"Count the bits of value 1 in an integer. Examples iex&gt; BitOps.count_ones(0) 0 iex&gt; BitOps.count_ones(3) 2 iex&gt; BitOps.count_ones(0b111_0000_1111) 7"},{"ref":"BitOps.html#get_bit/2","title":"BitOps.get_bit/2","type":"function","doc":"Get the value of the bit at the index. Examples iex&gt; BitOps.get_bit(0b101, 0) 1 iex&gt; BitOps.get_bit(0b101, 1) 0 iex&gt; BitOps.get_bit(0b101, 99) 0"},{"ref":"BitOps.html#list_ones/1","title":"BitOps.list_ones/1","type":"function","doc":"Return a list of all indexes with bit value 1. Examples iex&gt; BitOps.list_ones(0) [] iex&gt; BitOps.list_ones(0b1011) [0, 1, 3]"},{"ref":"BitOps.html#set_bit/2","title":"BitOps.set_bit/2","type":"function","doc":"Set the bit at index to 1. Examples iex&gt; BitOps.set_bit(0b101, 1) 7 iex&gt; BitOps.set_bit(0, 8) 256"},{"ref":"BitOps.html#stream_ones/1","title":"BitOps.stream_ones/1","type":"function","doc":"Returns a stream function yielding the indexes with bit value 1. The stream lazily traverses the bits of the integer as needed. Examples iex&gt; my_stream = BitOps.stream_ones(0b1010_1110) iex&gt; my_stream |&gt; is_function true iex&gt; my_stream |&gt; Stream.map(&amp;(&amp;1 * 10)) |&gt; Enum.to_list [10, 20, 30, 50, 70]"},{"ref":"BitOps.html#unset_bit/2","title":"BitOps.unset_bit/2","type":"function","doc":"Set the bit at index to 0. Examples iex&gt; BitOps.unset_bit(0b101, 0) 4 iex&gt; BitOps.unset_bit(0b111, 2) 3"},{"ref":"UintSet.html","title":"UintSet","type":"module","doc":"Functions that work on sets of integers &gt;= 0. UintSet is an alternative set type in Elixir emulating the MapSet interface as closely as possible. Many of the UintSet doctests and unit tests were adapted from MapSet. UintSet illustrates the construction of a functional data structure from scratch, implementing the Inspect, Enumerable, and Collectable protocols. An UintSet can contain only non-negative integers. By definition, sets contain unique elements. Trying to insert a duplicate is a no-op: iex&gt; uint_set = UintSet.new() #UintSet&lt;[]&gt; iex&gt; uint_set = UintSet.put(uint_set, 3) #UintSet&lt;[3]&gt; iex&gt; uint_set |&gt; UintSet.put(2) |&gt; UintSet.put(3) #UintSet&lt;[2, 3]&gt; UintSet.new/1 accepts an enumerable of elements: iex&gt; UintSet.new(1..5) #UintSet&lt;[1, 2, 3, 4, 5]&gt; An UintSet is represented internally using the %UintSet{} struct. This struct can be used whenever there&#39;s a need to pattern match on something being an UintSet: iex&gt; match?(%UintSet{}, UintSet.new()) true The %UintSet{} struct contains a single field—bits— an integer which is used as a bit vector where each bit set to 1 represents a number present in the set. An empty set is stored as bits = 0: iex&gt; empty = UintSet.new() iex&gt; empty.bits 0 iex&gt; UintSet.member?(empty, 0) false A set containing just a 0 is stored as bits = 1, because the bit at 0 is set, so the element 0 is present: iex&gt; set_with_zero = UintSet.new([0]) iex&gt; set_with_zero.bits 1 iex&gt; UintSet.member?(set_with_zero, 0) true A set with a 2 is stored as bits = 4, because the bit at 2 is set, so the element 2 is present: iex&gt; set_with_two = UintSet.new([2]) iex&gt; set_with_two.bits 4 iex&gt; UintSet.member?(set_with_two, 2) true A set with the elements 0 and 1 is stored as bits = 3, because 3 is 0b11, so the bits at 0 and 1 are set: iex&gt; set_with_zero_and_one = UintSet.new([0, 1]) #UintSet&lt;[0, 1]&gt; iex&gt; set_with_zero_and_one.bits 3 The UintSet.new/1 function also accepts a keyword argument setting the initial value of the bits field: iex&gt; UintSet.new(bits: 13) #UintSet&lt;[0, 2, 3]&gt; This is easier to understand using base 2 notation for the argument: iex&gt; UintSet.new(bits: 0b1101) #UintSet&lt;[0, 2, 3]&gt; UintSets can also be constructed starting from other collection-type data structures: for example, see UintSet.new/1 or Enum.into/2. All the content of an UintSet is represented by a single integer, which in Elixir is limited only by available memory. Using an integer as a bit vector allows set operations like union and intersection to be implemented using fast bitwise operators. See the source code of UintSet.union and UintSet.intersection. A bit vector is efficient only for storing sets of small integers, or high-density sets where a large percentage of the possible elements are present. The memory usage is proportional only to the largest element stored, not to the number of elements present. If the largest element in a set is 1_000_000, the raw bits will take 125_000 bytes (⅛), regardless of the number of elements in the set. This package was inspired by the intset example from chapter 6 of The Go Programming Language, by Alan. A. A. Donovan and Brian W. Kernighan."},{"ref":"UintSet.html#delete/2","title":"UintSet.delete/2","type":"function","doc":"Deletes value from uint_set. Returns a new set which is a copy of uint_set but without value. Examples iex&gt; uint_set = UintSet.new([1, 2, 3]) iex&gt; UintSet.delete(uint_set, 4) #UintSet&lt;[1, 2, 3]&gt; iex&gt; UintSet.delete(uint_set, 2) #UintSet&lt;[1, 3]&gt;"},{"ref":"UintSet.html#difference/2","title":"UintSet.difference/2","type":"function","doc":"Returns a set that is uint_set1 without the members of uint_set2. Examples iex&gt; UintSet.difference(UintSet.new([1, 2]), UintSet.new([2, 3, 4])) #UintSet&lt;[1]&gt;"},{"ref":"UintSet.html#disjoint?/2","title":"UintSet.disjoint?/2","type":"function","doc":"Checks if uint_set1 and uint_set2 have no members in common. Examples iex&gt; UintSet.disjoint?(UintSet.new([1, 2]), UintSet.new([3, 4])) true iex&gt; UintSet.disjoint?(UintSet.new([1, 2]), UintSet.new([2, 3])) false"},{"ref":"UintSet.html#equal?/2","title":"UintSet.equal?/2","type":"function","doc":"Checks if two sets are equal. Examples iex&gt; UintSet.equal?(UintSet.new([1, 2]), UintSet.new([2, 1, 1])) true iex&gt; UintSet.equal?(UintSet.new([1, 2]), UintSet.new([3, 4])) false"},{"ref":"UintSet.html#intersection/2","title":"UintSet.intersection/2","type":"function","doc":"Returns a set containing only members that uint_set1 and uint_set2 have in common. Examples iex&gt; UintSet.intersection(UintSet.new([1, 2]), UintSet.new([2, 3, 4])) #UintSet&lt;[2]&gt; iex&gt; UintSet.intersection(UintSet.new([1, 2]), UintSet.new([3, 4])) #UintSet&lt;[]&gt;"},{"ref":"UintSet.html#length/1","title":"UintSet.length/1","type":"function","doc":"Returns the number of elements in uint_set. This function is named length because it needs to traverse the uint_set, so it runs in O(n) time. The corresponding function in MapSet is size. Example iex&gt; UintSet.length(UintSet.new([10, 20, 30])) 3"},{"ref":"UintSet.html#member?/2","title":"UintSet.member?/2","type":"function","doc":"Checks if uint_set contains value. Examples iex&gt; UintSet.member?(UintSet.new([1, 2, 3]), 2) true iex&gt; UintSet.member?(UintSet.new([1, 2, 3]), 4) false"},{"ref":"UintSet.html#new/0","title":"UintSet.new/0","type":"function","doc":"Returns a new empty UintSet. Example iex&gt; UintSet.new() #UintSet&lt;[]&gt;"},{"ref":"UintSet.html#new/1","title":"UintSet.new/1","type":"function","doc":"Creates a set from an enumerable. Examples iex&gt; UintSet.new([10, 5, 7]) #UintSet&lt;[5, 7, 10]&gt; iex&gt; UintSet.new(3..7) #UintSet&lt;[3, 4, 5, 6, 7]&gt; iex&gt; UintSet.new([3, 3, 3, 2, 2, 1]) #UintSet&lt;[1, 2, 3]&gt;"},{"ref":"UintSet.html#new/2","title":"UintSet.new/2","type":"function","doc":"Creates a set from an enumerable via the transformation function. Examples iex&gt; UintSet.new([1, 3, 1], fn x -&gt; 2 * x end) #UintSet&lt;[2, 6]&gt;"},{"ref":"UintSet.html#put/2","title":"UintSet.put/2","type":"function","doc":"Inserts value into uint_set if uint_set doesn&#39;t already contain it. Examples iex&gt; UintSet.put(UintSet.new([1, 2, 3]), 3) #UintSet&lt;[1, 2, 3]&gt; iex&gt; UintSet.put(UintSet.new([1, 2, 3]), 4) #UintSet&lt;[1, 2, 3, 4]&gt;"},{"ref":"UintSet.html#stream/1","title":"UintSet.stream/1","type":"function","doc":"Returns a stream function yielding the elements of uint_set one by one in ascending order. The stream lazily traverses the bits of the uint_set as needed. Examples iex&gt; my_stream = UintSet.new([10, 5, 7]) |&gt; UintSet.stream iex&gt; my_stream |&gt; is_function true iex&gt; my_stream |&gt; Stream.map(&amp;(&amp;1 * 10)) |&gt; Enum.to_list [50, 70, 100]"},{"ref":"UintSet.html#subset?/2","title":"UintSet.subset?/2","type":"function","doc":"Checks if uint_set1&#39;s members are all contained in uint_set2. This function checks if uint_set1 is a subset of uint_set2. Examples iex&gt; UintSet.subset?(UintSet.new([1, 2]), UintSet.new([1, 2, 3])) true iex&gt; UintSet.subset?(UintSet.new([1, 2, 3]), UintSet.new([1, 2])) false"},{"ref":"UintSet.html#to_list/1","title":"UintSet.to_list/1","type":"function","doc":"Converts uint_set to a list. Examples iex&gt; UintSet.to_list(UintSet.new([2, 3, 1])) [1, 2, 3]"},{"ref":"UintSet.html#union/2","title":"UintSet.union/2","type":"function","doc":"Returns a set containing all members of uint_set1 and uint_set2. Examples iex&gt; UintSet.union(UintSet.new([1, 2]), UintSet.new([2, 3, 4])) #UintSet&lt;[1, 2, 3, 4]&gt;"}]